@@ -2,7 +2,7 @@ create.bspline.basis <- function (rangeval=NULL, nbasis=NULL,
                                   norder=4,        breaks=NULL,
                                   dropind=NULL,    quadvals=NULL,
                                   values=NULL,     basisvalues=NULL,
-                                  names="bspl")
+                                  names="bspl", axes=NULL)
 {
 #  This function creates a bspline functional data basis.
 #  Arguments
@@ -325,10 +325,13 @@ create.bspline.basis <- function (rangeval=NULL, nbasis=NULL,
       if(length(names)>1)
         stop('length(names) = ', length(names), ';  must be either ',
              '1 or nbasis = ', nbasis)
-      paste(names, norder, ".", 1:nbasis, sep="")
+      basisobj$names <- paste(names, norder, ".", 1:nbasis, sep="")
     }
   }
-
+##
+## 9.  Done
+##
+  if(!is.null(axes))basisobj$axes <- axes
   basisobj
 
 }
